@@ -1,9 +1,7 @@
 package Yars::Tools;
 
-# ABSTRACT: various utility functions dealing with servers, hosts, etc
-our $VERSION = '0.91'; # VERSION
-
-
+use strict;
+use warnings;
 use Clustericious::Config;
 use List::Util qw/shuffle/;
 use List::MoreUtils qw/uniq/;
@@ -23,8 +21,11 @@ use Mojo::ByteStream qw/b/;
 use File::HomeDir;
 use File::Spec;
 use Mojo::UserAgent;
-use strict;
-use warnings;
+use File::Spec;
+
+
+# ABSTRACT: various utility functions dealing with servers, hosts, etc
+our $VERSION = '0.92'; # VERSION
 
 
 sub new
@@ -169,6 +170,38 @@ sub disk_is_up {
 }
 
 
+sub disk_is_up_verified
+{
+    my($self, $root) = @_;
+    return unless $self->disk_is_up($root);
+    my $tmpdir = File::Spec->catdir($root, 'tmp');
+    my $temp;
+    eval {
+        use autodie;
+        unless(-d $tmpdir)
+        {
+            mkpath $tmpdir;
+            chmod 0777, $tmpdir;
+        };
+        $temp = File::Temp->new("disk_is_up_verifiedXXXXX", DIR => $tmpdir, SUFFIX => '.txt');
+        print $temp "test";
+        close $temp;
+        die "file has zero size" if -z $temp->filename;
+        unlink $temp->filename;
+    };
+    if(my $error = $@)
+    {
+        INFO "Create temp file in $tmpdir FAILED: $error";
+        return;
+    }
+    else
+    {
+        INFO "created temp file to test status: " . $temp->filename;
+        return 1;
+    }
+}
+
+
 sub disk_is_down {
     return not shift->disk_is_up(@_);
 }
@@ -394,17 +427,19 @@ sub b642hex {
 
 1;
 
-
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Yars::Tools - various utility functions dealing with servers, hosts, etc
 
 =head1 VERSION
 
-version 0.91
+version 0.92
 
 =head1 DESCRIPTION
 
@@ -435,6 +470,12 @@ Given a disk root, return true unless the disk is marked down.
 A disk is down if the state file indicates it, or if it exists
 but is unwriteable.
 
+=head2 disk_is_up_verified
+
+This is the same as disk_is_up, but doesn't trust the operating system, and
+tries to write a file to the disk's temp directory and verify that the file
+is not of zero size.
+
 =head2 disk_is_down
 
 Disk is not up.
@@ -542,4 +583,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
